@@ -14,14 +14,17 @@ def default_marshaller(obj):
     :return: the marshalled object state
 
     """
-    if hasattr(obj, '__getstate__'):
+    if hasattr(obj, "__getstate__"):
         return obj.__getstate__()
 
     try:
         return obj.__dict__
     except AttributeError:
-        raise TypeError('{!r} has no __dict__ attribute and does not implement __getstate__()'
-                        .format(qualified_name(obj.__class__))) from None
+        raise TypeError(
+            "{!r} has no __dict__ attribute and does not implement __getstate__()".format(
+                qualified_name(obj.__class__)
+            )
+        ) from None
 
 
 def default_unmarshaller(instance, state) -> None:
@@ -35,11 +38,14 @@ def default_unmarshaller(instance, state) -> None:
     :param state: the state object, as returned by :func:`default_marshaller`
 
     """
-    if hasattr(instance, '__setstate__'):
+    if hasattr(instance, "__setstate__"):
         instance.__setstate__(state)
     else:
         try:
             instance.__dict__.update(state)
         except AttributeError:
-            raise TypeError('{!r} has no __dict__ attribute and does not implement __setstate__()'
-                            .format(qualified_name(instance.__class__))) from None
+            raise TypeError(
+                "{!r} has no __dict__ attribute and does not implement __setstate__()".format(
+                    qualified_name(instance.__class__)
+                )
+            ) from None
